==> zio-aws-serverlessapplicationrepository_2.12-5.17.124.1-sources.jar: zio/aws/serverlessapplicationrepository/model/RollbackTrigger.scala <==
package zio.aws.serverlessapplicationrepository.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.serverlessapplicationrepository.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class RollbackTrigger(arn: __string, `type`: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.serverlessapplicationrepository.model.RollbackTrigger = {
    import RollbackTrigger.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.serverlessapplicationrepository.model.RollbackTrigger
      .builder()
      .arn(__string.unwrap(arn): java.lang.String)
      .`type`(__string.unwrap(`type`): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.serverlessapplicationrepository.model.RollbackTrigger.ReadOnly =
    zio.aws.serverlessapplicationrepository.model.RollbackTrigger
      .wrap(buildAwsValue())
}
object RollbackTrigger {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.serverlessapplicationrepository.model.RollbackTrigger
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.serverlessapplicationrepository.model.RollbackTrigger =
      zio.aws.serverlessapplicationrepository.model.RollbackTrigger(arn, `type`)
    def arn: __string
    def `type`: __string
    def getArn: ZIO[Any, Nothing, __string] = ZIO.succeed(arn)
    def getType: ZIO[Any, Nothing, __string] = ZIO.succeed(`type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.RollbackTrigger
  ) extends zio.aws.serverlessapplicationrepository.model.RollbackTrigger.ReadOnly {
    override val arn: __string =
      zio.aws.serverlessapplicationrepository.model.primitives
        .__string(impl.arn())
    override val `type`: __string =
      zio.aws.serverlessapplicationrepository.model.primitives
        .__string(impl.`type`())
  }
  def wrap(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.RollbackTrigger
  ): zio.aws.serverlessapplicationrepository.model.RollbackTrigger.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-serverlessapplicationrepository_2.13-5.17.130.7-sources.jar: zio/aws/serverlessapplicationrepository/model/RollbackTrigger.scala <==
package zio.aws.serverlessapplicationrepository.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.serverlessapplicationrepository.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class RollbackTrigger(arn: __string, `type`: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.serverlessapplicationrepository.model.RollbackTrigger = {
    import RollbackTrigger.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.serverlessapplicationrepository.model.RollbackTrigger
      .builder()
      .arn(arn: java.lang.String)
      .`type`(`type`: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.serverlessapplicationrepository.model.RollbackTrigger.ReadOnly =
    zio.aws.serverlessapplicationrepository.model.RollbackTrigger
      .wrap(buildAwsValue())
}
object RollbackTrigger {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.serverlessapplicationrepository.model.RollbackTrigger
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.serverlessapplicationrepository.model.RollbackTrigger =
      zio.aws.serverlessapplicationrepository.model.RollbackTrigger(arn, `type`)
    def arn: __string
    def `type`: __string
    def getArn: ZIO[Any, Nothing, __string] = ZIO.succeed(arn)
    def getType: ZIO[Any, Nothing, __string] = ZIO.succeed(`type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.RollbackTrigger
  ) extends zio.aws.serverlessapplicationrepository.model.RollbackTrigger.ReadOnly {
    override val arn: __string = impl.arn(): __string
    override val `type`: __string = impl.`type`(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.RollbackTrigger
  ): zio.aws.serverlessapplicationrepository.model.RollbackTrigger.ReadOnly =
    new Wrapper(impl)
}
